@@ -453,7 +453,7 @@ additiveValueFunctionElicitation <- function(performanceTable, criteriaMinMax, e
   # -------------------------------------------------------
   
   if ((numAlt >= 3) && !is.null(alternativesRanks))
-    tau = Kendall(alternativesRanks,outRanks)$tau[1]
+    tau = cor(alternativesRanks,outRanks,method="kendall")
   else
     tau = NULL
   
